"use strict";

exports.Renderer = Renderer;
var _storyContentFormat = require("@prezly/story-content-format");
var Elements = require("./elements/index.cjs");
var _index2 = require("./lib/index.cjs");
var _index3 = require("./selector/index.cjs");
var Transformations = require("./transformations/index.cjs");
var _jsxRuntime = require("react/jsx-runtime");
function Renderer(_ref) {
  var {
    children,
    coverageEntries = {},
    defaultComponents = true,
    defaultFallback = 'warning',
    nodes,
    renderDate = defaultRenderDate,
    transformations = Object.values(Transformations)
  } = _ref;
  var transformedNodes = (0, _index2.applyTransformations)(Array.isArray(nodes) ? nodes : [nodes], transformations);
  function renderCoverageNode(props) {
    var coverage = coverageEntries[props.node.coverage.id];
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(Elements.Coverage, {
      coverage: coverage,
      node: props.node,
      renderDate: renderDate
    });
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_index3.Selector, {
    nodes: transformedNodes,
    children: [children, defaultComponents && /*#__PURE__*/(0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.AttachmentNode.isAttachmentNode,
        component: Elements.Attachment
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.ButtonBlockNode.isButtonBlockNode,
        component: Elements.ButtonBlock
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.BookmarkNode.isBookmarkNode,
        component: Elements.Bookmark
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.CalloutNode.isCalloutNode,
        component: Elements.Callout
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.ContactNode.isContactNode,
        component: Elements.Contact
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.CoverageNode.isCoverageNode,
        component: renderCoverageNode
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.DividerNode.isDividerNode,
        component: Elements.Divider
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.DocumentNode.isDocumentNode,
        component: Elements.Document
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.EmbedNode.isEmbedNode,
        component: Elements.Embed
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.GalleryNode.isGalleryNode,
        component: Elements.Gallery
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.HeadingNode.isHeadingNode,
        component: Elements.Heading
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.HtmlNode.isHtmlNode,
        component: Elements.Html
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.ImageNode.isImageNode,
        component: Elements.Image
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.LinkNode.isLinkNode,
        component: Elements.Link
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.ListNode.isListNode,
        component: Elements.List
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.ListItemNode.isListItemNode,
        component: Elements.ListItem
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.ListItemTextNode.isListItemTextNode,
        component: Elements.ListItemText
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.ParagraphNode.isParagraphNode,
        component: Elements.Paragraph
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.PlaceholderNode.isPlaceholderNode,
        component: Elements.Ignore
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.QuoteNode.isQuoteNode,
        component: Elements.Quote
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.Text.isText,
        component: Elements.Text
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.VariableNode.isVariableNode,
        component: Elements.Variable
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.VideoNode.isVideoNode,
        component: Elements.Video
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.TableNode.isTableNode,
        component: Elements.Table
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: _storyContentFormat.TableRowNode.isTableRowNode,
        component: Elements.TableRow
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
        match: isTableCellNode,
        component: Elements.TableCell
      })]
    }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.Component, {
      match: isAnyNode,
      component: fallback(defaultFallback)
    })]
  });
}
function fallback(defaultFallback) {
  if (defaultFallback === 'ignore') return Elements.Ignore;
  if (defaultFallback === 'passthru') return Elements.Passthru;
  if (defaultFallback === 'warning') return Elements.Unknown;
  return defaultFallback;
}
function defaultRenderDate(date) {
  return new Date(date).toLocaleDateString();
}
function isAnyNode(_) {
  return true;
}
function isTableCellNode(node) {
  return _storyContentFormat.TableCellNode.isTableCellNode(node);
}