'use client';

import { useEventListener } from '@react-hookz/web';
import classNames from 'classnames';
import { useEffect } from 'react';
import Modal from 'react-modal';
import { ChevronLeft, ChevronRight, Close } from "../../icons/index.mjs";
import { noop } from "../../lib/index.mjs";
import { Media } from "../Media/index.mjs";
import { PinterestButton } from "../PinterestButton/index.mjs";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
export function Lightbox(_ref) {
  var {
    children,
    className,
    image,
    isNextEnabled,
    isPreviousEnabled,
    onClose,
    onDownload = noop,
    onNext = noop,
    onOpen = noop,
    onPrevious = noop,
    previewImage = defaultPreviewImage,
    title
  } = _ref;
  useEventListener(typeof window !== 'undefined' ? window : globalThis, 'keydown', event => {
    if (image === null) {
      return;
    }
    if (event.key === 'Esc') {
      onClose();
    }
    if (event.key === 'ArrowLeft') {
      onPrevious();
    }
    if (event.key === 'ArrowRight') {
      onNext();
    }
  });
  useEffect(() => {
    if (image) {
      onOpen(image);
    }
    // TODO: Address this. Simply adding `onOpen` to the deps might introduce an infinite loop.
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [image]);
  if (typeof window === 'undefined') {
    // Do not render Lightbox outside of browser environment (i.e. SSR)
    return null;
  }
  if (image === null) {
    return /*#__PURE__*/_jsx(Modal, {
      className: classNames('prezly-slate-lightbox', className),
      isOpen: false
      // This functionality has issues on React 18.
      ,
      ariaHideApp: false
    });
  }
  return /*#__PURE__*/_jsxs(Modal, {
    className: classNames('prezly-slate-lightbox', className),
    isOpen: true,
    onRequestClose: onClose
    // This functionality has issues on React 18.
    ,
    ariaHideApp: false,
    children: [/*#__PURE__*/_jsxs("figure", {
      className: "prezly-slate-lightbox__figure",
      children: [/*#__PURE__*/_jsxs("div", {
        className: "prezly-slate-lightbox__nav",
        children: [/*#__PURE__*/_jsx("button", {
          className: "prezly-slate-lightbox__nav-button",
          disabled: !isPreviousEnabled,
          onClick: onPrevious,
          type: "button",
          title: "Previous (Left Arrow)",
          children: /*#__PURE__*/_jsx(ChevronLeft, {
            className: "prezly-slate-lightbox__nav-button-icon"
          })
        }), /*#__PURE__*/_jsx("button", {
          className: "prezly-slate-lightbox__nav-button",
          disabled: !isNextEnabled,
          onClick: onNext,
          type: "button",
          title: "Next (Right Arrow)",
          children: /*#__PURE__*/_jsx(ChevronRight, {
            className: "prezly-slate-lightbox__nav-button-icon"
          })
        })]
      }), /*#__PURE__*/_jsxs("div", {
        className: "prezly-slate-lightbox__image-container",
        children: [/*#__PURE__*/_jsx(Media, {
          className: "prezly-slate-lightbox__image",
          image: previewImage(image),
          title: title
        }), /*#__PURE__*/_jsxs("div", {
          className: "prezly-slate-lightbox__actions",
          children: [/*#__PURE__*/_jsx("a", {
            className: "prezly-slate-lightbox__download",
            download: true,
            href: image.downloadUrl,
            rel: "nofollow noreferrer noopener",
            target: "_blank",
            title: "Download full-size",
            onClick: () => onDownload(image),
            children: "Download full-size"
          }), /*#__PURE__*/_jsx(PinterestButton, {
            className: "prezly-slate-lightbox__pinterest",
            image: previewImage(image).cdnUrl
          })]
        })]
      }), /*#__PURE__*/_jsx("div", {
        className: "prezly-slate-lightbox__caption",
        children: children
      })]
    }), /*#__PURE__*/_jsx("button", {
      className: "prezly-slate-lightbox__close",
      onClick: onClose,
      type: "button",
      title: "Close (Esc)",
      children: /*#__PURE__*/_jsx(Close, {
        className: "prezly-slate-lightbox__close-icon"
      })
    })]
  });
}
function defaultPreviewImage(image) {
  return image.preview(2000, 2000);
}